==> mozc-1.10.1390.102.tar.bz2: mozc-1.10.1390.102/gui/dictionary_tool/dictionary_tool_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DictionaryTool</name>
    <message>
        <location filename="dictionary_tool.ui" line="14"/>
        <source>Mozc Dictionary Tool</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.ui" line="31"/>
        <source>toolBar</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <location filename="find_dialog.ui" line="26"/>
        <source>Mozc Dictionary Find Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="37"/>
        <source>Reading or Word:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="54"/>
        <source>Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="61"/>
        <source>Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="68"/>
        <source>Cacnel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="import_dialog.ui" line="26"/>
        <source>Mozc Dictionary Tool</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="75"/>
        <source>File Location</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="82"/>
        <source>Dictionary Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="89"/>
        <source>Format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="96"/>
        <source>Encoding</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="103"/>
        <source>Select file...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="dictionary_tool.cc" line="98"/>
        <location filename="dictionary_tool.cc" line="108"/>
        <source>Sync-able dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="274"/>
        <source>Importing new words...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>mozc::gui::DictionaryTool</name>
    <message>
        <location filename="dictionary_tool.cc" line="300"/>
        <source>Mozc</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="329"/>
        <source>Another process is accessing the user dictionary file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="393"/>
        <source>Reading</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="393"/>
        <source>Word</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="394"/>
        <source>Comment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="427"/>
        <source>New dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1367"/>
        <source>Rename...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1368"/>
        <source>Delete</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="433"/>
        <source>Import as new dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="435"/>
        <source>Import to current dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="508"/>
        <source>User Dictionary 1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="677"/>
        <location filename="dictionary_tool.cc" line="754"/>
        <source>You can&apos;t have more than %1 dictionaries.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="682"/>
        <source>Name of the new dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="696"/>
        <location filename="dictionary_tool.cc" line="725"/>
        <location filename="dictionary_tool.cc" line="776"/>
        <location filename="dictionary_tool.cc" line="925"/>
        <location filename="dictionary_tool.cc" line="967"/>
        <source>No dictionary is selected.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="702"/>
        <source>Do you want to delete %1?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="731"/>
        <source>New name of the dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1286"/>
        <source>Move the selected words to</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1508"/>
        <source>Dictionary name is empty.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1513"/>
        <source>Dictionary name is too long.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1503"/>
        <source>An invalid character is included in the dictionary name.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="345"/>
        <source>Add</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="436"/>
        <source>Export current dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="972"/>
        <source>Export dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="346"/>
        <source>Remove</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="344"/>
        <source>Tools</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="394"/>
        <source>Category</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="429"/>
        <source>Delete dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="782"/>
        <location filename="dictionary_tool.cc" line="1002"/>
        <source>You can&apos;t have more than %1 words in one dictionary.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="931"/>
        <source>All user-registered words in %1 are migrated into the current dictionary.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="835"/>
        <source>Failed to open user dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="973"/>
        <source>Text Files (*.txt);;All Files (*)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="851"/>
        <location filename="dictionary_tool.cc" line="981"/>
        <source>Can&apos;t open %1.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="428"/>
        <source>Rename dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="430"/>
        <source>Find...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="443"/>
        <source>Import from %1&apos;s user dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="554"/>
        <source>Making dangerously large user dictionary file. If the dictionary file turns out to be larger than 256Mbyte, the dictionary loader skips to handle all the words to prevent the converter from being halted.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="638"/>
        <source>Updating the current view data...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="806"/>
        <source>%1 entries are imported to %2.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="812"/>
        <source>You have imported a file in an invalid or unsupported file format.

Please check the file format. ATOK11 or older format is not supported by Mozc.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="821"/>
        <source>%1 doesn&apos;t have enough space to import all words in the file. First %2 entries are imported.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="828"/>
        <source>%1 entries are imported to %2.

Some imported words were not recognized by %3. Please check the original import file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="916"/>
        <source>Microsoft IME dictioanry import function doesn&apos;t work on UAC-elevated process.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="994"/>
        <source>Dictionary export finished.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1064"/>
        <source>Do you want to delete this word?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1066"/>
        <source>Do you want to delete the selected words?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1080"/>
        <source>Deleting the selected words...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1151"/>
        <source>Cannot move all the selected items.
The target dictionary can have maximum %1 entries.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1164"/>
        <source>Moving the selected words...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1208"/>
        <source>New comment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1240"/>
        <source>An invalid character is included in the reading.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1273"/>
        <source>Add a word</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1278"/>
        <source>Delete this word</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1285"/>
        <source>Delete the selected words</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1279"/>
        <source>Move this word to</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1315"/>
        <source>Change category to</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1323"/>
        <source>Edit comment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1370"/>
        <source>Import to this dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1371"/>
        <source>Export this dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1518"/>
        <source>Dictionary already exists.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1523"/>
        <source>A fatal error occurred.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1641"/>
        <source>%1: %2 entries</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>mozc::gui::FindDialog</name>
    <message>
        <location filename="find_dialog.cc" line="127"/>
        <source>Cannot find pattern %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>mozc::gui::ImportDialog</name>
    <message>
        <location filename="import_dialog.cc" line="26"/>
        <location filename="import_dialog.cc" line="55"/>
        <source>Auto detection</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="29"/>
        <source>Google</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="34"/>
        <location filename="import_dialog.cc" line="50"/>
        <source>Microsoft IME</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="37"/>
        <location filename="import_dialog.cc" line="47"/>
        <source>ATOK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="40"/>
        <location filename="import_dialog.cc" line="44"/>
        <source>Kotoeri</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="58"/>
        <source>Unicode</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="61"/>
        <source>Shift JIS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="64"/>
        <source>UTF-8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="69"/>
        <source>Import</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="161"/>
        <source>Import dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="163"/>
        <source>Text Files (*.txt);;All Files (*)</source>
        <translation></translation>
    </message>
</context>
</TS>

==> mozc_1.12.1599.102.orig.tar.bz2: mozc-1.12.1599.102/gui/dictionary_tool/dictionary_tool_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DictionaryTool</name>
    <message>
        <location filename="dictionary_tool.ui" line="14"/>
        <source>Mozc Dictionary Tool</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.ui" line="31"/>
        <source>toolBar</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <location filename="find_dialog.ui" line="26"/>
        <source>Mozc Dictionary Find Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="37"/>
        <source>Reading or Word:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="54"/>
        <source>Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="61"/>
        <source>Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="68"/>
        <source>Cacnel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="import_dialog.ui" line="26"/>
        <source>Mozc Dictionary Tool</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="75"/>
        <source>File Location</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="82"/>
        <source>Dictionary Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="89"/>
        <source>Format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="96"/>
        <source>Encoding</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="103"/>
        <source>Select file...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="dictionary_tool.cc" line="98"/>
        <location filename="dictionary_tool.cc" line="108"/>
        <source>Sync-able dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="274"/>
        <source>Importing new words...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>mozc::gui::DictionaryTool</name>
    <message>
        <location filename="dictionary_tool.cc" line="300"/>
        <source>Mozc</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="329"/>
        <source>Another process is accessing the user dictionary file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="393"/>
        <source>Reading</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="393"/>
        <source>Word</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="394"/>
        <source>Comment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="427"/>
        <source>New dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1367"/>
        <source>Rename...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1368"/>
        <source>Delete</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="433"/>
        <source>Import as new dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="435"/>
        <source>Import to current dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="508"/>
        <source>User Dictionary 1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="677"/>
        <location filename="dictionary_tool.cc" line="754"/>
        <source>You can&apos;t have more than %1 dictionaries.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="682"/>
        <source>Name of the new dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="696"/>
        <location filename="dictionary_tool.cc" line="725"/>
        <location filename="dictionary_tool.cc" line="776"/>
        <location filename="dictionary_tool.cc" line="925"/>
        <location filename="dictionary_tool.cc" line="967"/>
        <source>No dictionary is selected.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="702"/>
        <source>Do you want to delete %1?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="731"/>
        <source>New name of the dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1286"/>
        <source>Move the selected words to</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1508"/>
        <source>Dictionary name is empty.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1513"/>
        <source>Dictionary name is too long.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1503"/>
        <source>An invalid character is included in the dictionary name.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="345"/>
        <source>Add</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="436"/>
        <source>Export current dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="972"/>
        <source>Export dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="346"/>
        <source>Remove</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="344"/>
        <source>Tools</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="394"/>
        <source>Category</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="429"/>
        <source>Delete dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="782"/>
        <location filename="dictionary_tool.cc" line="1002"/>
        <source>You can&apos;t have more than %1 words in one dictionary.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="931"/>
        <source>All user-registered words in %1 are migrated into the current dictionary.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="835"/>
        <source>Failed to open user dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="973"/>
        <source>Text Files (*.txt);;All Files (*)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="851"/>
        <location filename="dictionary_tool.cc" line="981"/>
        <source>Can&apos;t open %1.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="428"/>
        <source>Rename dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="430"/>
        <source>Find...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="443"/>
        <source>Import from %1&apos;s user dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="554"/>
        <source>Making dangerously large user dictionary file. If the dictionary file turns out to be larger than 256Mbyte, the dictionary loader skips to handle all the words to prevent the converter from being halted.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="638"/>
        <source>Updating the current view data...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="806"/>
        <source>%1 entries are imported to %2.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="812"/>
        <source>You have imported a file in an invalid or unsupported file format.

Please check the file format. ATOK11 or older format is not supported by Mozc.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="821"/>
        <source>%1 doesn&apos;t have enough space to import all words in the file. First %2 entries are imported.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="828"/>
        <source>%1 entries are imported to %2.

Some imported words were not recognized by %3. Please check the original import file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="916"/>
        <source>Microsoft IME dictionary import function doesn&apos;t work on UAC-elevated process.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="994"/>
        <source>Dictionary export finished.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1064"/>
        <source>Do you want to delete this word?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1066"/>
        <source>Do you want to delete the selected words?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1080"/>
        <source>Deleting the selected words...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1151"/>
        <source>Cannot move all the selected items.
The target dictionary can have maximum %1 entries.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1164"/>
        <source>Moving the selected words...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1208"/>
        <source>New comment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1240"/>
        <source>An invalid character is included in the reading.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1273"/>
        <source>Add a word</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1278"/>
        <source>Delete this word</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1285"/>
        <source>Delete the selected words</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1279"/>
        <source>Move this word to</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1315"/>
        <source>Change category to</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1323"/>
        <source>Edit comment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1370"/>
        <source>Import to this dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1371"/>
        <source>Export this dictionary...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1518"/>
        <source>Dictionary already exists.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1523"/>
        <source>A fatal error occurred.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1641"/>
        <source>%1: %2 entries</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>mozc::gui::FindDialog</name>
    <message>
        <location filename="find_dialog.cc" line="127"/>
        <source>Cannot find pattern %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>mozc::gui::ImportDialog</name>
    <message>
        <location filename="import_dialog.cc" line="26"/>
        <location filename="import_dialog.cc" line="55"/>
        <source>Auto detection</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="29"/>
        <source>Google</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="34"/>
        <location filename="import_dialog.cc" line="50"/>
        <source>Microsoft IME</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="37"/>
        <location filename="import_dialog.cc" line="47"/>
        <source>ATOK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="40"/>
        <location filename="import_dialog.cc" line="44"/>
        <source>Kotoeri</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="58"/>
        <source>Unicode</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="61"/>
        <source>Shift JIS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="64"/>
        <source>UTF-8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="69"/>
        <source>Import</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="161"/>
        <source>Import dictionary</source>
        <translation></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="163"/>
        <source>Text Files (*.txt);;All Files (*)</source>
        <translation></translation>
    </message>
</context>
</TS>
